package com.srs.comprehensive.mapper;

import java.util.List;
import com.srs.comprehensive.domain.CphAuditDetails;
import com.srs.comprehensive.domain.SrsAddRecord;
import com.srs.comprehensive.domain.Vo.CheckIam;
import org.apache.ibatis.annotations.Mapper;

/**
 * 审核明细Mapper接口
 *
 * @author 邓
 * @date 2023-07-04
 */
@Mapper
public interface CphAuditDetailsMapper
{
    /**
     * 查询审核明细
     *
     * @param id 审核明细主键
     * @return 审核明细
     */
    public CphAuditDetails selectCphAuditDetailsById(Long id);

    public CphAuditDetails selectCphAuditDetailsByProjectId(Long id);

    /**
     * 查询审核明细列表
     *
     * @param cphAuditDetails 审核明细
     * @return 审核明细集合
     */
    public List<CphAuditDetails> selectCphAuditDetailsList(CphAuditDetails cphAuditDetails);

    /**
     * 查询已审核
     * @author zhy
     * @date 2023-07-06 11:36:44
     * @param cad
     * @return
     **/
    public List<CphAuditDetails> listMyProcessed(CphAuditDetails cad);

    /**
     * 审核查询
     * @param cphAuditDetails
     * @return
     */
    public List<CphAuditDetails> searchCphAuditDetailsList(CphAuditDetails cphAuditDetails);


    /**
     * 新增审核明细
     *
     * @param cphAuditDetails 审核明细
     * @return 结果
     */
    public int insertCphAuditDetails(CphAuditDetails cphAuditDetails);

    /**
     * 修改审核明细
     *
     * @param cphAuditDetails 审核明细
     * @return 结果
     */
    public int updateCphAuditDetails(CphAuditDetails cphAuditDetails);

    /**
     * 删除审核明细
     *
     * @param id 审核明细主键
     * @return 结果
     */
    public int deleteCphAuditDetailsById(Long id);

    /**
     * 批量删除审核明细
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCphAuditDetailsByIds(Long[] ids);
    public int cancelAuditById(Long id);
    public int cancelCphAudiDetailsById(Long id);

    //查询审核状态不对的加分记录
    public List<SrsAddRecord> listCancelRecord();

    public List<CheckIam> checkIamList();

    public List<CphAuditDetails> listCheckAudit(CheckIam param);

    public List<SrsAddRecord> ListCheckRecord(CheckIam param);

}
